% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/laplace-distribution.R
\name{Laplace}
\alias{Laplace}
\alias{dlaplace}
\alias{plaplace}
\alias{qlaplace}
\alias{rlaplace}
\title{Laplace distribution}
\usage{
dlaplace(x, mu = 0, sigma = 1, log = FALSE)

plaplace(q, mu = 0, sigma = 1, lower.tail = TRUE, log.p = FALSE)

qlaplace(p, mu = 0, sigma = 1, lower.tail = TRUE, log.p = FALSE)

rlaplace(n, mu = 0, sigma = 1)
}
\arguments{
\item{x, q}{vector of quantiles.}

\item{mu, sigma}{location and scale parameters. Scale must be positive.}

\item{log, log.p}{logical; if TRUE, probabilities p are given as log(p).}

\item{lower.tail}{logical; if TRUE (default), probabilities are \eqn{P[X \le x]}
otherwise, \eqn{P[X > x]}.}

\item{p}{vector of probabilities.}

\item{n}{number of observations. If \code{length(n) > 1},
the length is taken to be the number required.}
}
\description{
Density, distribution function, quantile function and random generation
for the Laplace distribution.
}
\details{
Probability density function
\deqn{
f(x) = \frac{1}{2\sigma} \exp(-|z|)
}{
f(x) = 1/(2*\sigma) * exp(-|z|)
}

Cumulative distribution function
\deqn{ F(x) = \left\{\begin{array}{ll}
\frac{1}{2} \exp(z)     & x < \mu \\
1 - \frac{1}{2} \exp(z) & x \geq \mu
\end{array}\right.
}{
F(x) = [if x < mu:] 1/2 * exp(z)
       [else:] 1 - 1/2 * exp(z)
}

Quantile function
\deqn{ F^{-1}(p) = \left\{\begin{array}{ll}
\mu + \sigma \log(2p)     & p < 0.5 \\
\mu + \sigma \log(2(1-p)) & p \geq 0.5
\end{array}\right.
}{
F^-1(p) = [if p < 0.5:] \mu + \sigma * log(2*p)
          [else:] \mu + \sigma * log(2*(1-p))
}

where \eqn{ z = \frac{x-\mu}{\sigma} }{ z = (x-\mu)/\sigma }.
}
\examples{

x <- rlaplace(1e5, 5, 16)
xx <- seq(-100, 100, by = 0.01)
hist(x, 100, freq = FALSE)
lines(xx, dlaplace(xx, 5, 16), col = "red")
hist(plaplace(x, 5, 16))
plot(ecdf(x))
lines(xx, plaplace(xx, 5, 16), col = "red", lwd = 2)

X <- rexp(1e5, 1/5)
Y <- rbern(1e5, 0.5)
hist(X*(Y*2 - 1), freq = FALSE, 100)
lines(xx, dlaplace(xx, 0, 5), col = "red")

}
\references{
Krishnamoorthy, K. (2006). Handbook of Statistical Distributions
with Applications. Chapman & Hall/CRC

Forbes, C., Evans, M. Hastings, N., & Peacock, B. (2011).
Statistical Distributions. John Wiley & Sons.
}
\keyword{distribution}

